﻿using System.Threading.Tasks;
using FluentAssertions;
using Microsoft.AspNetCore.Mvc;
using NSubstitute;
using System;
using Website.Controllers;
using Website.Data;
using Website.Models.Blog;
using Website.Models.Git;
using Website.ViewModels;
using Website.ViewModels.Blog;
using Xunit;

namespace Website.Tests.Controllers {
	public class HomeControllerTests {
		[Fact]
		public async Task Index_ReturnsViewWithModel() {
			var blogApi = Substitute.For<IBlogApi>();
			var gitApi = Substitute.For<IGitApi>();

			blogApi.GetLatestPostAsync().Returns(new BlogPost { Content = "" });

			var repo = new Repository();
			gitApi.GetRepositories("rob").Returns(new[] { repo });
			gitApi.GetBranches("rob", repo).Returns(new[] { new Branch { Commit = new() { Timestamp = DateTimeOffset.Now }, Repository = repo} });
			gitApi.GetCommit("rob", null, null).Returns(new Commit());

			var expectation = new HomeViewModel {
				BlogPost = new BlogPostViewModel(new BlogPost { Content = "" }, false),
				GitCommit = new GitCommitViewModel(repo, new Branch { Commit = new Commit() }, new Commit())
			};

			var controller = new HomeController(blogApi, gitApi);
			(await controller.Index() as ViewResult).Model.Should().BeEquivalentTo(expectation);
		}
	}
}