﻿using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Website.Data;
using Website.ViewModels;
using System.Linq;
using Website.ViewModels.Blog;

namespace Website.Controllers {
	public class HomeController : Controller {
		private readonly IBlogApi _blogApi;
		private readonly IGitApi _gitApi;

		public HomeController(IBlogApi blogApi, IGitApi gitApi) {
			_gitApi = gitApi;
			_blogApi = blogApi;
		}

		public async Task<IActionResult> Index() {
			var post = await _blogApi.GetLatestPostAsync();
			var repos = await _gitApi.GetRepositories("rob");

			var branchTasks = repos.Select(repo => _gitApi.GetBranches("rob", repo));
			var branchResults = await Task.WhenAll(branchTasks);
			var branches = branchResults.SelectMany(branch => branch);
			var branch = branches.OrderByDescending(branch => branch.Commit.Timestamp).First();

			var commit = await _gitApi.GetCommit("rob", branch.Repository.Name, branch.Commit.Id);

			var model = new HomeViewModel {
				BlogPost = new BlogPostViewModel(post, false),
				GitCommit = new GitCommitViewModel(branch.Repository, branch, commit)
			};

			return View(model);
		}
	}
}