﻿using System.Collections.Generic;
using System.Net.Http;
using System.Threading.Tasks;
using Microsoft.Extensions.Caching.Memory;
using Robware.Lib.ApiClient;
using System;
using System.Linq;
using Website.Models.Git;

namespace Website.Data {
	public class GitApi : ApiClient, IGitApi {

		public GitApi(HttpClient client, IMemoryCache cache, CacheDurations cacheDurations) : base(client, cache, cacheDurations) {
		}

		public async Task<IEnumerable<Repository>> GetRepositories(string user) {
			try {
				return await Get<IEnumerable<Repository>>("repositories", new { user });
			}
			catch (Exception e) {
				Console.WriteLine(e);
				return [new() { Name = "Unable to get repositories", Url = "https://git.robware.uk" }];
			}
		}

		public async Task<IEnumerable<Branch>> GetBranches(string user, Repository repository) {
			try {
				var branches = await Get<IEnumerable<Branch>>("branches", new { user, repository = repository.Name });
				return branches.Select(branch => branch with { Repository = repository });
			}
			catch (Exception e) {
				Console.WriteLine(e);
				return [
					new() {
						Name = "Unable to get branches",
						Commit = new() { Url = "https://git.robware.uk", Id = "000000", Message = "Unable to get commit", Timestamp = DateTimeOffset.Now },
						Repository = repository,
					}
				];
			}
		}

		public async Task<Commit> GetCommit(string user, string repository, string hash) {
			try {
				return await Get<Commit>("commit", new { user, repository, hash });
			}
			catch (Exception e) {
				Console.WriteLine(e);
				return new() { Url = "https://git.robware.uk", Id = "000000", Message = "Unable to get commit", Timestamp = DateTimeOffset.Now };
			}
		}
	}
}