﻿using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Website.Data;

namespace Website.ViewComponents {
	public class ProjectNavigationViewComponent :ViewComponent {
		private readonly IGitApi _gitApi;

		public ProjectNavigationViewComponent(IGitApi gitApi) {
			_gitApi = gitApi;
		}

		public async Task<IViewComponentResult> InvokeAsync() {
			var repos = await _gitApi.GetRepositories("rob");

			var branchTasks = repos.Select(repo => _gitApi.GetBranches("rob", repo));
			var branchResults = await Task.WhenAll(branchTasks);
			var branches = branchResults.SelectMany(branch => branch);
			var sortedBranches = branches.OrderByDescending(branch => branch.Commit.Timestamp);
			var sortedRepos = sortedBranches.DistinctBy(branch => branch.Repository).Select(branch => branch.Repository);
			
			return View(sortedRepos.Take(5));
		}
	}
}